@@ -164,7 +164,7 @@ extern int Create(char *mddev, int mdfd,
 
 extern int Detail(char *dev, int brief);
 extern int Query(char *dev);
-extern int Examine(mddev_dev_t devlist, int brief, int scan);
+extern int Examine(mddev_dev_t devlist, int brief, int scan, int SparcAdjust);
 extern int Monitor(mddev_dev_t devlist,
 		   char *mailaddr, char *alert_cmd,
 		   int period, int scan,
@@ -202,3 +202,4 @@ char *human_size_brief(long long bytes);
 extern void put_md_name(char *name);
 extern char *get_md_name(int dev);
 
+extern char DefaultConfFile[];
